# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""Calculate Window U-w as per ISO-10077-2:2006"""

import warnings

try:
    from ladybug_geometry.geometry3d import LineSegment3D, face
except ImportError as e:
    raise ImportError("Failed to import ladybug_geometry from ladybug_geometry.")

try:
    from honeybee import aperture
except ImportError as e:
    raise ImportError("Failed to import honeybee from honeybee.")

try:
    from honeybee_energy_ph.construction import window
except ImportError as e:
    raise ImportError("Failed to import honeybee_energy_ph from honeybee_energy_ph.")


def get_ladybug_Face3D_width_and_height(_lbt_face3d):
    # type: (face.Face3D) -> tuple[float, float]
    """Get the width and height of a ladybug_geometry.geometry3d.face.Face3D object.

    If a non-rectangular object with more than 4 vertices is passed, a ValueError is raised.
    """

    if len(_lbt_face3d.vertices) != 4:
        raise ValueError(
            "The LBT-Face3D '{}' has {} vertices. Only use rectangular faces with 4 vertices.".format(
                _lbt_face3d, len(_lbt_face3d.vertices)
            )
        )

    (
        vertix_upper_left,
        vertix_upper_right,
        vertix_lower_right,
        vertix_lower_left,
    ) = _lbt_face3d.upper_left_counter_clockwise_vertices
    horizontal_edge = LineSegment3D.from_end_points(vertix_upper_left, vertix_upper_right)
    vertical_edge = LineSegment3D.from_end_points(vertix_upper_right, vertix_lower_right)

    height = horizontal_edge.length
    width = vertical_edge.length

    return width, height


def get_honeybee_aperture_width_and_height(_hb_aperture):
    # type: (aperture.Aperture) -> tuple[float, float]
    """Get the width and height of a rectangular honeybee.aperture.Aperture object.

    If a non-rectangular object with more than 4 vertices is passed, a ValueError is raised.
    """
    if len(_hb_aperture.geometry.vertices) != 4:
        raise ValueError(
            "The HB-Aperture '{}' has {} vertices. Only use rectangular Apertures with 4 vertices.".format(
                _hb_aperture.display_name, len(_hb_aperture.geometry.vertices)
            )
        )

    return get_ladybug_Face3D_width_and_height(_hb_aperture.geometry)


class ISO100771Data:
    """Wrapper class used to calculate the ISO-10077-1 heat-loss values."""

    def __init__(self, _win_width, _win_height, _frame, _glazing):
        # type: (float, float, window.PhWindowFrame, window.PhWindowGlazing) -> None
        self.win_width = _win_width
        self.win_height = _win_height
        self.frame = _frame
        self.glazing = _glazing

    @classmethod
    def from_hb_aperture(cls, _hb_aperture):
        # type: (aperture.Aperture) -> ISO100771Data
        """Create an ISO100771Data object from a honeybee.aperture.Aperture object."""

        hbe_prop = _hb_aperture.properties.energy  # type: ignore

        try:
            ph_frame = hbe_prop.construction.properties.ph.ph_frame
        except Exception as e:
            raise Exception("The Aperture does not have a PH-Style frame.", e)

        try:
            ph_glazing = hbe_prop.construction.properties.ph.ph_glazing
        except Exception as e:
            raise Exception("The Aperture does not have a PH-Style glazing.", e)

        (
            w,
            h,
        ) = get_honeybee_aperture_width_and_height(_hb_aperture)
        return cls(
            w,
            h,
            ph_frame,
            ph_glazing,
        )

    @classmethod
    def from_lbt_Face3D(cls, _hb_face3d, _ph_frame, _ph_glazing):
        # type: (face.Face3D, window.PhWindowFrame, window.PhWindowGlazing) -> ISO100771Data
        """Create an ISO100771Data object from a ladybug_geometry.geometry3d.face.Face3D object."""

        (
            w,
            h,
        ) = get_ladybug_Face3D_width_and_height(_hb_face3d)
        return cls(
            w,
            h,
            _ph_frame,
            _ph_glazing,
        )

    @property
    def area_window(self):
        # type: () -> float
        return self.side_exterior_length("right") * self.side_exterior_length("top")

    @property
    def area_glazing(self):
        # type: () -> float
        return self.side_interior_length("right") * self.side_interior_length("top")

    def side_interior_length(self, _side):
        # type: (str) -> float
        side_lengths = {
            "top": (self.win_width - self.frame.right.width - self.frame.left.width),
            "right": (self.win_height - self.frame.top.width - self.frame.bottom.width),
            "bottom": (self.win_width - self.frame.right.width - self.frame.left.width),
            "left": (self.win_height - self.frame.top.width - self.frame.bottom.width),
        }
        return side_lengths[_side]

    def side_exterior_length(self, _side):
        # type: (str) -> float
        side_lengths = {
            "top": self.win_width,
            "right": self.win_height,
            "bottom": self.win_width,
            "left": self.win_height,
        }
        return side_lengths[_side]

    def corner_area(self, _side):
        # type: (str) -> float
        """Correct for the overlap / 45 degrees at the corners"""

        adjacent_frames = {
            "top": {"adj_1": "left", "adj_2": "right"},
            "right": {"adj_1": "top", "adj_2": "bottom"},
            "bottom": {"adj_1": "left", "adj_2": "right"},
            "left": {"adj_1": "top", "adj_2": "bottom"},
        }

        base_frame = getattr(self.frame, _side)
        adjacent_frame_1 = getattr(self.frame, adjacent_frames[_side]["adj_1"])
        adjacent_frame_2 = getattr(self.frame, adjacent_frames[_side]["adj_2"])

        left_corner_area = base_frame.width * adjacent_frame_1.width
        right_corner_area = base_frame.width * adjacent_frame_2.width
        corner_area = ((left_corner_area) / 2) + ((right_corner_area) / 2)

        return corner_area

    def side_area(self, _side):
        # type: (str) -> float
        frame_element = getattr(self.frame, _side)
        # -- base area
        base_area = frame_element.width * self.side_interior_length(_side)
        return base_area + self.corner_area(_side)

    def side_frame_heat_loss(self, _side):
        # type: (str) -> float
        frame_element = getattr(self.frame, _side)
        return frame_element.u_factor * self.side_area(_side)

    def side_psi_glazing_heat_lost(self, _side):
        # type: (str) -> float
        frame_element = getattr(self.frame, _side)
        return frame_element.psi_glazing * self.side_interior_length(_side)

    def side_psi_install_heat_lost(self, _side):
        # type: (str) -> float
        frame_element = getattr(self.frame, _side)
        return frame_element.psi_install * self.side_exterior_length(_side)

    @property
    def heat_loss_frame(self):
        # type: () -> float
        return sum(
            [
                self.side_frame_heat_loss("top"),
                self.side_frame_heat_loss("right"),
                self.side_frame_heat_loss("bottom"),
                self.side_frame_heat_loss("left"),
            ]
        )

    @property
    def heat_loss_psi_glazing(self):
        # type: () -> float
        return sum(
            [
                self.side_psi_glazing_heat_lost("top"),
                self.side_psi_glazing_heat_lost("right"),
                self.side_psi_glazing_heat_lost("bottom"),
                self.side_psi_glazing_heat_lost("left"),
            ]
        )

    @property
    def heat_loss_psi_install(self):
        # type: () -> float
        return sum(
            [
                self.side_psi_install_heat_lost("top"),
                self.side_psi_install_heat_lost("right"),
                self.side_psi_install_heat_lost("bottom"),
                self.side_psi_install_heat_lost("left"),
            ]
        )

    @property
    def heat_loss_glazing(self):
        # type: () -> float
        return self.area_glazing * self.glazing.u_factor

    @property
    def uw(self):
        # type: () -> float
        return (
            self.heat_loss_glazing + self.heat_loss_frame + self.heat_loss_psi_glazing + self.heat_loss_psi_install
        ) / self.area_window


def build_standard_window(_frame, _glazing):
    # type: (window.PhWindowFrame, window.PhWindowGlazing) -> ISO100771Data
    """A standard-size (1.23m x 1.48m) window as per ISO 10077-2:2006, As per Annex F (2006)"""
    width = 1.23  # M
    height = 1.48  # M
    return ISO100771Data(width, height, _frame, _glazing)


def calculate_window_frame_factor(_frame, _glazing):
    # type: (window.PhWindowFrame, window.PhWindowGlazing) -> float
    """Calculate the frame factor for a standard-size (1.23m x 1.48m) window as per ISO 10077-2:2006, Annex-F"""
    window = build_standard_window(_frame, _glazing)
    return window.area_glazing / window.area_window


# -----------------------------------------------------------------------------
# -- Functions to calculate U-w -----------------------------------------------


def calculate_window_uw(_frame, _glazing):
    # type: (window.PhWindowFrame, window.PhWindowGlazing) -> float
    """Calculate U-w (W/m2k) for a standard-size (1.23m x 1.48m) window as per ISO 10077-2:2006, Annex-F
    This value includes the impact of the frame, glazing, glazing-spacers, and the psi-install heat loss.
    """

    warnings.warn(
        "The 'function calculate_window_uw' is deprecated and will be removed in a future version. Use function 'calculate_standard_window_uw' instead.",
        DeprecationWarning,
    )

    window = build_standard_window(_frame, _glazing)
    return window.uw


def calculate_standard_window_uw(_frame, _glazing):
    # type: (window.PhWindowFrame, window.PhWindowGlazing) -> float
    """Calculate U-w (W/m2k) for a standard-size window as per ISO 10077-2:2006
    This value includes the impact of the frame, glazing, glazing-spacers, and the psi-install heat loss.
    """

    window = build_standard_window(_frame, _glazing)
    return window.uw


def calculate_hb_aperture_uw(_hb_aperture):
    # type: (aperture.Aperture) -> float
    """Calculate U-W (W/m2k) for a 'honeybee.aperture.Aperture' with PH-Style frame and glazing as per ISO 10077-2:2006
    This value includes the impact of the frame, glazing, glazing-spacers, and the psi-install heat loss.
    """
    window = ISO100771Data.from_hb_aperture(_hb_aperture)
    return window.uw


def calculate_lbt_Face3D_uw(_hb_face3d, _ph_frame, _ph_glazing):
    # type: (face.Face3D, window.PhWindowFrame, window.PhWindowGlazing) -> float
    """Calculate U-w (W/m2k) for a 'ladybug_geometry.geometry3d.face.Face3D' as per ISO 10077-2:2006
    This value includes the impact of the frame, glazing, glazing-spacers, and the psi-install heat loss.
    """

    window = ISO100771Data.from_lbt_Face3D(_hb_face3d, _ph_frame, _ph_glazing)
    return window.uw



# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""Honeybee-PH-HVAC-Equipment: Ducts."""

from math import radians

try:
    from typing import Any, Dict, List, Optional, Union
except ImportError:
    pass  # IronPython

try:
    from ladybug_geometry.geometry3d.pointvector import Point3D
    from ladybug_geometry.geometry3d.polyline import LineSegment3D
except ImportError as e:
    raise ImportError("\nFailed to import ladybug_geometry:\n\t{}".format(e))

try:
    from honeybee_phhvac import _base
except ImportError as e:
    raise ImportError("\nFailed to import honeybee_phhvac:\n\t{}".format(e))


class PhDuctSegment(_base._PhHVACBase):
    """A single duct segment (linear) with geometry and a attributes.

    Note: All geometric information is in the model's unit-type (meters by default).
    """

    def __init__(
        self,
        _geom,
        _insul_thickness=0.0254,
        _insul_conductivity=0.04,
        _insul_refl=True,
        _diameter=0.160,
        _height=None,
        _width=None,
    ):
        # type: (LineSegment3D, float, float, bool, float, Optional[float], Optional[float]) -> None
        super(PhDuctSegment, self).__init__()
        self.geometry = _geom
        self.insulation_thickness = _insul_thickness
        self.insulation_conductivity = _insul_conductivity
        self.insulation_reflective = _insul_refl
        self.diameter = _diameter
        self.height = _height
        self.width = _width

    @property
    def length(self):
        # type: () -> float
        """Return the length of the duct segment in model-units."""
        return self.geometry.length

    @property
    def shape_type(self):
        # type: () -> int
        if (self.height is not None) and (self.width is not None):
            return 2  # Rectangular Duct
        else:
            return 1  # Round Duct

    @property
    def is_round_duct(self):
        # type: () -> bool
        return self.shape_type == 1

    @property
    def shape_type_description(self):
        # type: () -> str
        """Return a string description of the shape of the duct segment."""
        if self.is_round_duct:
            return "{:.3f} Θ".format(float(self.diameter))
        else:
            return "{:.3f} x {:.3f}".format(self.width or 0.0, self.height or 0.0)

    @classmethod
    def default(cls):
        # type: () -> PhDuctSegment
        """Return a default Duct segment with a length of 1.0"""

        pt1 = Point3D(0, 0, 0)
        pt2 = Point3D(1, 0, 0)
        geom = LineSegment3D.from_end_points(pt1, pt2)

        return cls(geom)

    def __copy__(self):
        # type: () -> PhDuctSegment
        new_obj = PhDuctSegment(self.geometry)

        new_obj.geometry = self.geometry
        new_obj.insulation_thickness = self.insulation_thickness
        new_obj.insulation_conductivity = self.insulation_conductivity
        new_obj.insulation_reflective = self.insulation_reflective
        new_obj.diameter = self.diameter
        new_obj.height = self.height
        new_obj.width = self.width
        new_obj.identifier = self.identifier
        new_obj.display_name = self.display_name
        new_obj.user_data = self.user_data

        return new_obj

    def duplicate(self):
        # type: () -> PhDuctSegment
        return self.__copy__()

    def to_dict(self):
        # type: () -> Dict[str, Union[str, dict]]
        d = super(PhDuctSegment, self).to_dict()

        d["geometry"] = self.geometry.to_dict()
        d["insulation_thickness"] = self.insulation_thickness
        d["insulation_conductivity"] = self.insulation_conductivity
        d["insulation_reflective"] = self.insulation_reflective
        d["diameter"] = self.diameter
        d["height"] = self.height
        d["width"] = self.width

        return d

    @classmethod
    def from_dict(cls, _input_dict):
        # type: (Dict) -> PhDuctSegment
        new_obj = cls(_geom=LineSegment3D.from_dict(_input_dict["geometry"]))
        new_obj.insulation_thickness = _input_dict["insulation_thickness"]
        new_obj.insulation_conductivity = _input_dict["insulation_conductivity"]
        new_obj.insulation_reflective = _input_dict["insulation_reflective"]
        new_obj.diameter = _input_dict["diameter"]
        new_obj.height = _input_dict["height"]
        new_obj.width = _input_dict["width"]
        new_obj.identifier = _input_dict["identifier"]
        new_obj.display_name = _input_dict["display_name"]
        new_obj.user_data = _input_dict["user_data"]

        return new_obj

    def __str__(self):
        return "{}: diam={}, length={:.3f}".format(self.__class__.__name__, self.diameter, self.length)

    def __repr__(self):
        return str(self)

    def ToString(self):
        return self.__repr__()

    def move(self, moving_vec3D):
        # type: (Point3D) -> PhDuctSegment
        """Move the duct segment along a vector.

        Args:
            moving_vec3D: A Vector3D with the direction and distance to move the ray.
        """
        new_segment = self.duplicate()
        new_segment.geometry = self.geometry.move(moving_vec3D)
        return new_segment

    def rotate(self, axis_vec3D, angle_degrees, origin_pt3D):
        # type: (Point3D, float, Point3D) -> PhDuctSegment
        """Rotate the duct segment by a certain angle around an axis and origin.

        Right hand rule applies:
        If axis has a positive orientation, rotation will be clockwise.
        If axis has a negative orientation, rotation will be counterclockwise.

        Args:
            axis_vec3D: A Vector3D axis representing the axis of rotation.
            angle_degrees: An angle for rotation in degrees.
            origin_pt3D: A Point3D for the origin around which the object will be rotated.
        """
        new_segment = self.duplicate()
        new_segment.geometry = self.geometry.rotate(axis_vec3D, radians(angle_degrees), origin_pt3D)
        return new_segment

    def rotate_xy(self, angle_degrees, origin_pt3D):
        # type: (float, Point3D) -> PhDuctSegment
        """Rotate the duct segment counterclockwise in the XY plane by a certain angle.

        Args:
            angle_degrees: An angle in degrees.
            origin_pt3D: A Point3D for the origin around which the object will be rotated.
        """
        new_segment = self.duplicate()
        new_segment.geometry = self.geometry.rotate_xy(radians(angle_degrees), origin_pt3D)
        return new_segment

    def reflect(self, normal_vec3D, origin_pt3D):
        # type: (Point3D, Point3D) -> PhDuctSegment
        """Reflected the duct segment across a plane with the input normal vector and origin.

        Args:
            normal_vec3D: A Vector3D representing the normal vector for the plane across
                which the line segment will be reflected. THIS VECTOR MUST BE NORMALIZED.
            origin_pt3D: A Point3D representing the origin from which to reflect.
        """
        new_segment = self.duplicate()
        new_segment.geometry = self.geometry.reflect(normal_vec3D, origin_pt3D)
        return new_segment

    def scale(self, scale_factor, origin_pt3D=None):
        # type: (float, Optional[Point3D]) -> PhDuctSegment
        """Scale the duct segment by a factor from an origin point.

        Args:
            scale_factor: A number representing how much the line segment should be scaled.
            origin_pt3D: A Point3D representing the origin from which to scale.
                If None, it will be scaled from the World origin (0, 0, 0).
        """
        new_segment = self.duplicate()
        new_segment.geometry = self.geometry.scale(scale_factor, origin_pt3D)
        new_segment.insulation_thickness = self.insulation_thickness * scale_factor
        new_segment.diameter = self.diameter * scale_factor
        new_segment.height = scale_factor * self.height if self.height else None
        new_segment.width = scale_factor * self.width if self.width else None
        return new_segment


class PhDuctElement(_base._PhHVACBase):
    """A Duct Element made up of one or more individual Duct Segments.

    Note: All geometric information is in the model's unit-type (meters by default).
    """

    def __init__(self, _display_name=None, _duct_type=1, *args, **kwargs):
        # type: (Optional[str], int, *Any, **Any) -> None
        super(PhDuctElement, self).__init__()
        self.display_name = _display_name or self.identifier_short
        self.duct_type = _duct_type
        self._segments = {}  # type: Dict[str, PhDuctSegment]

    @property
    def segments(self):
        # type: () -> List[PhDuctSegment]
        """Return a list of all the PhDuctSegments that make up the PhDuctElement."""
        return list(self._segments.values())

    @property
    def length(self):
        # type: () -> float
        """Return the total duct length of all the PhDuctSegments in model-units."""
        return sum(s.length for s in self.segments)

    @property
    def is_round_duct(self):
        # type: () -> bool
        return self.shape_type == 1

    @property
    def shape_type(self):
        # type: () -> Optional[int]
        segment_types = {s.shape_type for s in self.segments}
        if len(segment_types) == 0:
            return None
        elif len(segment_types) == 1:
            return segment_types.pop()
        else:
            raise ValueError("Mixed shape-types in duct segments.")

    @property
    def shape_type_description(self):
        # type: () -> Optional[str]
        descriptions = {s.shape_type_description for s in self.segments}
        if len(descriptions) == 0:
            return None
        elif len(descriptions) == 1:
            return descriptions.pop()
        else:
            raise ValueError("Mixed shapes/sizes in duct segments.")

    @classmethod
    def default_supply_duct(cls, *args, **kwargs):
        # type: (*Any, **Any) -> PhDuctElement
        """Returns a default PhDuctElement with a single segment and a length of 1.0"""

        duct_element = cls(*args, **kwargs)
        duct_element.duct_type = 1
        duct_element.add_segment(PhDuctSegment.default())
        return duct_element

    @classmethod
    def default_exhaust_duct(cls, *args, **kwargs):
        # type: (*Any, **Any) -> PhDuctElement
        """Returns a default PhDuctElement with a single segment and a length of 1.0"""

        duct_element = cls(*args, **kwargs)
        duct_element.duct_type = 2
        duct_element.add_segment(PhDuctSegment.default())
        return duct_element

    def add_segment(self, _segment):
        # type: (PhDuctSegment) -> None
        """Add a new PhDuctSegment to the Duct Element."""
        # -- Check that the new segment is the right shape type
        if len(self.segments) > 0:
            if not _segment.shape_type == self.shape_type:
                msg = "Error: Cannot join round and rectangular duct segments."
                raise Exception(msg)
        self._segments[_segment.identifier] = _segment

    def clear_segments(self):
        # type: () -> None
        """Clear all the segments from the duct element."""
        self._segments = {}

    def __copy__(self):
        # type: () -> PhDuctElement
        new_obj = PhDuctElement()

        for segment in self.segments:
            new_obj.add_segment(segment.duplicate())

        new_obj.identifier = self.identifier
        new_obj.display_name = self.display_name
        new_obj.duct_type = self.duct_type
        new_obj.user_data = self.user_data

        return new_obj

    def duplicate(self):
        # type: () -> PhDuctElement
        return self.__copy__()

    def to_dict(self):
        # type: () -> Dict[str, Union[str, dict]]
        d = super(PhDuctElement, self).to_dict()

        d["segments"] = {}
        for segment in self.segments:
            d["segments"][segment.identifier] = segment.to_dict()
        d["duct_type"] = self.duct_type

        return d

    @classmethod
    def from_dict(cls, _input_dict):
        # type: (Dict) -> PhDuctElement
        new_obj = cls()

        for seg_dict in _input_dict["segments"].values():
            new_obj._segments[seg_dict["identifier"]] = PhDuctSegment.from_dict(seg_dict)
        new_obj.identifier = _input_dict["identifier"]
        new_obj.display_name = _input_dict["display_name"]
        new_obj.duct_type = _input_dict["duct_type"]
        new_obj.user_data = _input_dict["user_data"]

        return new_obj

    def __str__(self):
        return "{}: (display_name={}, identifier={} ) [{} segments, len={:.3f}]".format(
            self.__class__.__name__,
            self.display_name,
            self.identifier,
            len(self.segments),
            self.length,
        )

    def __repr__(self):
        return str(self)

    def ToString(self):
        return self.__repr__()

    def move(self, moving_vec3D):
        """Move the duct element's segment along a vector.

        Args:
            moving_vec3D: A Vector3D with the direction and distance to move the ray.
        """
        new_element = self.duplicate()
        new_element.clear_segments()
        for segment in self.segments:
            new_element.add_segment(segment.move(moving_vec3D))
        return new_element

    def rotate(self, axis_vec3D, angle_degrees, origin_pt3D):
        """Rotate the duct element's segment by a certain angle around an axis and origin.

        Right hand rule applies:
        If axis has a positive orientation, rotation will be clockwise.
        If axis has a negative orientation, rotation will be counterclockwise.

        Args:
            axis_vec3D: A Vector3D axis representing the axis of rotation.
            angle_degrees: An angle for rotation in degrees.
            origin_pt3D: A Point3D for the origin around which the object will be rotated.
        """
        new_element = self.duplicate()
        new_element.clear_segments()
        for segment in self.segments:
            new_element.add_segment(segment.rotate(axis_vec3D, angle_degrees, origin_pt3D))
        return new_element

    def rotate_xy(self, angle_degrees, origin_pt3D):
        """Rotate the duct element's segment counterclockwise in the XY plane by a certain angle.

        Args:
            angle_degree: An angle in degrees.
            origin_pt3D: A Point3D for the origin around which the object will be rotated.
        """
        new_element = self.duplicate()
        new_element.clear_segments()
        for segment in self.segments:
            new_element.add_segment(segment.rotate_xy(angle_degrees, origin_pt3D))
        return new_element

    def reflect(self, normal_vec3D, origin_pt3D):
        """Reflected the duct element's segment across a plane with the input normal vector and origin.

        Args:
            normal_vec3D: A Vector3D representing the normal vector for the plane across
                which the line segment will be reflected. THIS VECTOR MUST BE NORMALIZED.
            origin_pt3D: A Point3D representing the origin from which to reflect.
        """
        new_element = self.duplicate()
        new_element.clear_segments()
        for segment in self.segments:
            new_element.add_segment(segment.reflect(normal_vec3D, origin_pt3D))
        return new_element

    def scale(self, scale_factor, origin_pt3D=None):
        # type: (float, Optional[Point3D]) -> PhDuctElement
        """Scale the duct element's segments by a factor from an origin point.

        Args:
            scale_factor: A number representing how much the line segment should be scaled.
            origin_pt3D: A Point3D representing the origin from which to scale.
                If None, it will be scaled from the World origin (0, 0, 0).
        """
        new_element = self.duplicate()
        new_element.clear_segments()
        for segment in self.segments:
            new_element.add_segment(segment.scale(scale_factor, origin_pt3D))
        return new_element



# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""Phius Program Data Library"""

try:
    from typing import Any, Dict
except ImportError:
    pass  # IronPython 2.7


# Programs from:
# - PHIUS Guidebook, Table N-10, v3.02 | July 2021
# - Honeybee ASHRAE 90.1 2019 | IECC 2021
PHIUS_Non_Res = {
    "2021::PHIUS_NR::Assembly": {
        "name": "Assembly",
        "hb_base_program": "2019::Courthouse::Courtroom",
        "protocol": "PHIUS_NonRes",
        "description": "Fair/Congress building",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::Courthouse::Courtroom",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Assembly",
                "identifier": "2021::PHIUS_NR::Assembly",
                "start_hour": 13,
                "end_hour": 18,
                "annual_utilization_days": 150,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Assembly",
                "name": "2021::PHIUS_NR::Assembly",
                "people_per_area": 0.753474,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Assembly",
                "name": "2021::PHIUS_NR::Assembly",
                "daily_operating_hours": 5,
                "annual_utilization_days": 150,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Assembly",
                "name": "2021::PHIUS_NR::Assembly",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 12.91668,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Assembly",
                "name": "2021::PHIUS_NR::Assembly",
                "annual_utilization_factor": 0.473153,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Assembly",
                "name": "2021::PHIUS_NR::Assembly",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::Theater_Ticketing": {
        "name": "Theater Ticketing",
        "hb_base_program": "2019::Retail::Entry",
        "protocol": "PHIUS_NonRes",
        "description": "Booking hall",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", "2019::Retail::Entry"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Theater_Ticketing",
                "identifier": "2021::PHIUS_NR::Theater_Ticketing",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Ticketing",
                "name": "2021::PHIUS_NR::Theater_Ticketing",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Ticketing",
                "name": "2021::PHIUS_NR::Theater_Ticketing",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Ticketing",
                "name": "2021::PHIUS_NR::Theater_Ticketing",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 9.041676,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Ticketing",
                "name": "2021::PHIUS_NR::Theater_Ticketing",
                "annual_utilization_factor": 0.519583,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Ticketing",
                "name": "2021::PHIUS_NR::Theater_Ticketing",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::Canteen": {
        "name": "Canteen",
        "hb_base_program": "2019::QuickServiceRestaurant::Dining",
        "protocol": "PHIUS_NonRes",
        "description": "2021::PHIUS_NR::Canteen",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::QuickServiceRestaurant::Dining",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Canteen",
                "identifier": "2021::PHIUS_NR::Canteen",
                "start_hour": 8,
                "end_hour": 15,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Canteen",
                "name": "2021::PHIUS_NR::Canteen",
                "people_per_area": 0.753474,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Canteen",
                "name": "2021::PHIUS_NR::Canteen",
                "daily_operating_hours": 7,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Canteen",
                "name": "2021::PHIUS_NR::Canteen",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 6.45834,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Canteen",
                "name": "2021::PHIUS_NR::Canteen",
                "annual_utilization_factor": 0.164583,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Canteen",
                "name": "2021::PHIUS_NR::Canteen",
                "watts_per_m2": 116.788315,
            },
        },
    },
    "2021::PHIUS_NR::Hallway": {
        "name": "Hallway",
        "hb_base_program": "2019::MidriseApartment::Corridor",
        "protocol": "PHIUS_NonRes",
        "description": "Traffic / Circulation Areas",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::MidriseApartment::Corridor",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Hallway",
                "identifier": "2021::PHIUS_NR::Hallway",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.2,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hallway",
                "name": "2021::PHIUS_NR::Hallway",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Hallway",
                "name": "2021::PHIUS_NR::Hallway",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hallway",
                "name": "2021::PHIUS_NR::Hallway",
                "target_lux": 100,
                "target_lux_height": 0.0,
                "watts_per_m2": 5.381955,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Hallway",
                "name": "2021::PHIUS_NR::Hallway",
                "annual_utilization_factor": 0.245833,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hallway",
                "name": "2021::PHIUS_NR::Hallway",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::Classroom": {
        "name": "Classroom",
        "hb_base_program": "2019::PrimarySchool::Classroom",
        "protocol": "PHIUS_NonRes",
        "description": "Classroom (school and nursery school)",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::PrimarySchool::Classroom",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Classroom",
                "identifier": "2021::PHIUS_NR::Classroom",
                "start_hour": 8,
                "end_hour": 15,
                "annual_utilization_days": 200,
                "relative_utilization_factor": 0.75,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Classroom",
                "name": "2021::PHIUS_NR::Classroom",
                "people_per_area": 0.269098,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Classroom",
                "name": "2021::PHIUS_NR::Classroom",
                "daily_operating_hours": 7,
                "annual_utilization_days": 200,
                "relative_utilization_factor": 0.9,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Classroom",
                "name": "2021::PHIUS_NR::Classroom",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 7.642369,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Classroom",
                "name": "2021::PHIUS_NR::Classroom",
                "annual_utilization_factor": 0.442427,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Classroom",
                "name": "2021::PHIUS_NR::Classroom",
                "watts_per_m2": 14.999495,
            },
        },
    },
    "2021::PHIUS_NR::Garage_Private": {
        "name": "Garage Private",
        "hb_base_program": "2019::Courthouse::Parking",
        "protocol": "PHIUS_NonRes",
        "description": "Garage buildings for offices and private use",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::Courthouse::Parking",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Garage_Private",
                "identifier": "2021::PHIUS_NR::Garage_Private",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.05,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Garage_Private",
                "name": "2021::PHIUS_NR::Garage_Private",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Garage_Private",
                "name": "2021::PHIUS_NR::Garage_Private",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Garage_Private",
                "name": "2021::PHIUS_NR::Garage_Private",
                "target_lux": 75,
                "target_lux_height": 0.0,
                "watts_per_m2": 1.614585,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Garage_Private",
                "name": "2021::PHIUS_NR::Garage_Private",
                "annual_utilization_factor": 0.473153,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Garage_Private",
                "name": "2021::PHIUS_NR::Garage_Private",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::Garage_Public": {
        "name": "Garage Public",
        "hb_base_program": "2019::Courthouse::Parking",
        "protocol": "PHIUS_NonRes",
        "description": "Garage buildings for public use",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::Courthouse::Parking",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Garage_Public",
                "identifier": "2021::PHIUS_NR::Garage_Public",
                "start_hour": 9,
                "end_hour": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 0.2,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Garage_Public",
                "name": "2021::PHIUS_NR::Garage_Public",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Garage_Public",
                "name": "2021::PHIUS_NR::Garage_Public",
                "daily_operating_hours": 15,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Garage_Public",
                "name": "2021::PHIUS_NR::Garage_Public",
                "target_lux": 100,
                "target_lux_height": 0.0,
                "watts_per_m2": 1.614585,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Garage_Public",
                "name": "2021::PHIUS_NR::Garage_Public",
                "annual_utilization_factor": 0.473153,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Garage_Public",
                "name": "2021::PHIUS_NR::Garage_Public",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::Gym": {
        "name": "Gym",
        "hb_base_program": "2019::SmallHotel::Exercise",
        "protocol": "PHIUS_NonRes",
        "description": "Sports hall (without public viewing area)",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::SmallHotel::Exercise",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Gym",
                "identifier": "2021::PHIUS_NR::Gym",
                "start_hour": 8,
                "end_hour": 23,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 0.7,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Gym",
                "name": "2021::PHIUS_NR::Gym",
                "people_per_area": 0.214632,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Gym",
                "name": "2021::PHIUS_NR::Gym",
                "daily_operating_hours": 15,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Gym",
                "name": "2021::PHIUS_NR::Gym",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 9.68751,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Gym",
                "name": "2021::PHIUS_NR::Gym",
                "annual_utilization_factor": 0.4375,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Gym",
                "name": "2021::PHIUS_NR::Gym",
                "watts_per_m2": 18.621547,
            },
        },
    },
    "2021::PHIUS_NR::Hospital_Ward": {
        "name": "Hospital Ward",
        "hb_base_program": "2019::Hospital::PatRoom",
        "protocol": "PHIUS_NonRes",
        "description": "Hospital ward or dormitory",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", "2019::Hospital::PatRoom"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Hospital_Ward",
                "identifier": "2021::PHIUS_NR::Hospital_Ward",
                "start_hour": 8,
                "end_hour": 15,
                "annual_utilization_days": 200,
                "relative_utilization_factor": 0.75,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hospital_Ward",
                "name": "2021::PHIUS_NR::Hospital_Ward",
                "people_per_area": 0.05382,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Hospital_Ward",
                "name": "2021::PHIUS_NR::Hospital_Ward",
                "daily_operating_hours": 7,
                "annual_utilization_days": 200,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hospital_Ward",
                "name": "2021::PHIUS_NR::Hospital_Ward",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 7.319452,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Hospital_Ward",
                "name": "2021::PHIUS_NR::Hospital_Ward",
                "annual_utilization_factor": 0.594292,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hospital_Ward",
                "name": "2021::PHIUS_NR::Hospital_Ward",
                "watts_per_m2": 21.5278,
            },
        },
    },
    "2021::PHIUS_NR::Hotel_Bedroom": {
        "name": "Hotel Bedroom",
        "hb_base_program": "2019::LargeHotel::GuestRoom",
        "protocol": "PHIUS_NonRes",
        "description": "Hotel bedroom",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::LargeHotel::GuestRoom",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Hotel_Bedroom",
                "identifier": "2021::PHIUS_NR::Hotel_Bedroom",
                "start_hour": 21,
                "end_hour": 8,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 0.25,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hotel_Bedroom",
                "name": "2021::PHIUS_NR::Hotel_Bedroom",
                "people_per_area": 0.038427,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Hotel_Bedroom",
                "name": "2021::PHIUS_NR::Hotel_Bedroom",
                "daily_operating_hours": 11,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 0.3,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hotel_Bedroom",
                "name": "2021::PHIUS_NR::Hotel_Bedroom",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 4.413199,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Hotel_Bedroom",
                "name": "2021::PHIUS_NR::Hotel_Bedroom",
                "annual_utilization_factor": 0.315303,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Hotel_Bedroom",
                "name": "2021::PHIUS_NR::Hotel_Bedroom",
                "watts_per_m2": 6.748965,
            },
        },
    },
    "2021::PHIUS_NR::Kitchen_Commercial_Cooking": {
        "name": "Kitchen Commercial Cooking",
        "hb_base_program": "2019::FullServiceRestaurant::Kitchen",
        "protocol": "PHIUS_NonRes",
        "description": "Kitchen in non-residential buildings",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::FullServiceRestaurant::Kitchen",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "start_hour": 10,
                "end_hour": 23,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "people_per_area": 0.05382,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "daily_operating_hours": 13,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 11.732651,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "annual_utilization_factor": 0.164583,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Cooking",
                "watts_per_m2": 403.969167,
            },
        },
    },
    "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room": {
        "name": "Kitchen Commercial Prep Room",
        "hb_base_program": "2019::SuperMarket::Deli",
        "protocol": "PHIUS_NonRes",
        "description": "Kitchen preparation room or storeroom",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", "2019::SuperMarket::Deli"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "start_hour": 7,
                "end_hour": 23,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "people_per_area": 0.086111,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "daily_operating_hours": 16,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 11.732651,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "annual_utilization_factor": 0.606735,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "name": "2021::PHIUS_NR::Kitchen_Commercial_Prep_Room",
                "watts_per_m2": 8.934037,
            },
        },
    },
    "2021::PHIUS_NR::Laundry_Public": {
        "name": "Laundry Public",
        "hb_base_program": "2019::LargeHotel::Laundry",
        "protocol": "PHIUS_NonRes",
        "description": "Common Laundry",
        "source": ["MF_Calculator_2021", "2019::LargeHotel::Laundry"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Laundry_Public",
                "identifier": "2021::PHIUS_NR::Laundry_Public",
                "start_hour": 0,
                "end_hour": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Laundry_Public",
                "name": "2021::PHIUS_NR::Laundry_Public",
                "people_per_area": 0.107639,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Laundry_Public",
                "name": "2021::PHIUS_NR::Laundry_Public",
                "daily_operating_hours": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Laundry_Public",
                "name": "2021::PHIUS_NR::Laundry_Public",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 5.704867,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Laundry_Public",
                "name": "2021::PHIUS_NR::Laundry_Public",
                "annual_utilization_factor": 0.447888,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Laundry_Public",
                "name": "2021::PHIUS_NR::Laundry_Public",
                "watts_per_m2": 61.677147,
            },
        },
    },
    "2021::PHIUS_NR::Library_Reading_Room": {
        "name": "Library Reading Room",
        "hb_base_program": "2019::SecondarySchool::Library",
        "protocol": "PHIUS_NonRes",
        "description": "Library - reading rooms",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::SecondarySchool::Library",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Library_Reading_Room",
                "identifier": "2021::PHIUS_NR::Library_Reading_Room",
                "start_hour": 8,
                "end_hour": 20,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Reading_Room",
                "name": "2021::PHIUS_NR::Library_Reading_Room",
                "people_per_area": 0.107639,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Library_Reading_Room",
                "name": "2021::PHIUS_NR::Library_Reading_Room",
                "daily_operating_hours": 12,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Reading_Room",
                "name": "2021::PHIUS_NR::Library_Reading_Room",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 8.934037,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Library_Reading_Room",
                "name": "2021::PHIUS_NR::Library_Reading_Room",
                "annual_utilization_factor": 0.462476,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Reading_Room",
                "name": "2021::PHIUS_NR::Library_Reading_Room",
                "watts_per_m2": 10.010427,
            },
        },
    },
    "2021::PHIUS_NR::Library_Storage": {
        "name": "Library Storage",
        "hb_base_program": "2019::SecondarySchool::Library",
        "protocol": "PHIUS_NonRes",
        "description": "Library magazine and stores",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", ""],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Library_Storage",
                "identifier": "2021::PHIUS_NR::Library_Storage",
                "start_hour": 8,
                "end_hour": 20,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 0.1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Storage",
                "name": "2021::PHIUS_NR::Library_Storage",
                "people_per_area": 0.107639,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Library_Storage",
                "name": "2021::PHIUS_NR::Library_Storage",
                "daily_operating_hours": 12,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Storage",
                "name": "2021::PHIUS_NR::Library_Storage",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 8.934037,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Library_Storage",
                "name": "2021::PHIUS_NR::Library_Storage",
                "annual_utilization_factor": 0.462476,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Storage",
                "name": "2021::PHIUS_NR::Library_Storage",
                "watts_per_m2": 10.010427,
            },
        },
    },
    "2021::PHIUS_NR::Library_Stacks": {
        "name": "Library Stacks",
        "hb_base_program": "2019::SecondarySchool::Library",
        "protocol": "PHIUS_NonRes",
        "description": "Library-open stacks areas",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", ""],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Library_Stacks",
                "identifier": "2021::PHIUS_NR::Library_Stacks",
                "start_hour": 8,
                "end_hour": 20,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Stacks",
                "name": "2021::PHIUS_NR::Library_Stacks",
                "people_per_area": 0.107639,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Library_Stacks",
                "name": "2021::PHIUS_NR::Library_Stacks",
                "daily_operating_hours": 12,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Stacks",
                "name": "2021::PHIUS_NR::Library_Stacks",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 8.934037,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Library_Stacks",
                "name": "2021::PHIUS_NR::Library_Stacks",
                "annual_utilization_factor": 0.462476,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Library_Stacks",
                "name": "2021::PHIUS_NR::Library_Stacks",
                "watts_per_m2": 10.010427,
            },
        },
    },
    "2021::PHIUS_NR::Museum_Exhibition": {
        "name": "Museum Exhibition",
        "hb_base_program": "2019::Retail::Retail",
        "protocol": "PHIUS_NonRes",
        "description": "Exhibition rooms and museums with conservation requirements",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", "2019::Retail::Retail"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Museum_Exhibition",
                "identifier": "2021::PHIUS_NR::Museum_Exhibition",
                "start_hour": 10,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Museum_Exhibition",
                "name": "2021::PHIUS_NR::Museum_Exhibition",
                "people_per_area": 0.161459,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Museum_Exhibition",
                "name": "2021::PHIUS_NR::Museum_Exhibition",
                "daily_operating_hours": 8,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Museum_Exhibition",
                "name": "2021::PHIUS_NR::Museum_Exhibition",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 11.302095,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Museum_Exhibition",
                "name": "2021::PHIUS_NR::Museum_Exhibition",
                "annual_utilization_factor": 0.519583,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Museum_Exhibition",
                "name": "2021::PHIUS_NR::Museum_Exhibition",
                "watts_per_m2": 3.22917,
            },
        },
    },
    "2021::PHIUS_NR::Server_Room": {
        "name": "Server Room",
        "hb_base_program": "2019::MediumOffice::Elec/MechRoom",
        "protocol": "PHIUS_NonRes",
        "description": "Server room, computer center",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::MediumOffice::Elec/MechRoom",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Server_Room",
                "identifier": "2021::PHIUS_NR::Server_Room",
                "start_hour": 0,
                "end_hour": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Server_Room",
                "name": "2021::PHIUS_NR::Server_Room",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Server_Room",
                "name": "2021::PHIUS_NR::Server_Room",
                "daily_operating_hours": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Server_Room",
                "name": "2021::PHIUS_NR::Server_Room",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 4.628477,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Server_Room",
                "name": "2021::PHIUS_NR::Server_Room",
                "annual_utilization_factor": 0.467636,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Server_Room",
                "name": "2021::PHIUS_NR::Server_Room",
                "watts_per_m2": 2.906253,
            },
        },
    },
    "2021::PHIUS_NR::Manufacturing_Workshop": {
        "name": "Manufacturing Workshop",
        "hb_base_program": "2019::Laboratory::Open lab",
        "protocol": "PHIUS_NonRes",
        "description": "Workshop, assembly,manufacturing",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::Laboratory::Open lab",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Manufacturing_Workshop",
                "identifier": "2021::PHIUS_NR::Manufacturing_Workshop",
                "start_hour": 7,
                "end_hour": 16,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Manufacturing_Workshop",
                "name": "2021::PHIUS_NR::Manufacturing_Workshop",
                "people_per_area": 0.05382,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Manufacturing_Workshop",
                "name": "2021::PHIUS_NR::Manufacturing_Workshop",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Manufacturing_Workshop",
                "name": "2021::PHIUS_NR::Manufacturing_Workshop",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 14.315987,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Manufacturing_Workshop",
                "name": "2021::PHIUS_NR::Manufacturing_Workshop",
                "annual_utilization_factor": 0.307021,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Manufacturing_Workshop",
                "name": "2021::PHIUS_NR::Manufacturing_Workshop",
                "watts_per_m2": 43.0556,
            },
        },
    },
    "2021::PHIUS_NR::Office_Meeting_Room": {
        "name": "Office Meeting Room",
        "hb_base_program": "2019::LargeOffice::Conference",
        "protocol": "PHIUS_NonRes",
        "description": "Meeting conference and seminar room",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::LargeOffice::Conference",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Office_Meeting_Room",
                "identifier": "2021::PHIUS_NR::Office_Meeting_Room",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Meeting_Room",
                "name": "2021::PHIUS_NR::Office_Meeting_Room",
                "people_per_area": 0.538196,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Meeting_Room",
                "name": "2021::PHIUS_NR::Office_Meeting_Room",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Meeting_Room",
                "name": "2021::PHIUS_NR::Office_Meeting_Room",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 10.440983,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Meeting_Room",
                "name": "2021::PHIUS_NR::Office_Meeting_Room",
                "annual_utilization_factor": 0.512215,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Meeting_Room",
                "name": "2021::PHIUS_NR::Office_Meeting_Room",
                "watts_per_m2": 3.982643,
            },
        },
    },
    "2021::PHIUS_NR::Office_Workspace_Open": {
        "name": "Office Workspace Open",
        "hb_base_program": "2019::LargeOffice::OpenOffice",
        "protocol": "PHIUS_NonRes",
        "description": "Landscaped office (seven or more workplaces)",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::LargeOffice::OpenOffice",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Office_Workspace_Open",
                "identifier": "2021::PHIUS_NR::Office_Workspace_Open",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Open",
                "name": "2021::PHIUS_NR::Office_Workspace_Open",
                "people_per_area": 0.056511,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Open",
                "name": "2021::PHIUS_NR::Office_Workspace_Open",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Open",
                "name": "2021::PHIUS_NR::Office_Workspace_Open",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 6.565979,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Open",
                "name": "2021::PHIUS_NR::Office_Workspace_Open",
                "annual_utilization_factor": 0.512215,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Open",
                "name": "2021::PHIUS_NR::Office_Workspace_Open",
                "watts_per_m2": 7.642369,
            },
        },
    },
    "2021::PHIUS_NR::Office_Workspace_Semiopen": {
        "name": "Office Workspace Semiopen",
        "hb_base_program": "2019::LargeOffice::ClosedOffice",
        "protocol": "PHIUS_NonRes",
        "description": "Workgroup Office (2-6 workplaces)",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::LargeOffice::ClosedOffice",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "identifier": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.7,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "name": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "people_per_area": 0.051129,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "name": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.7,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "name": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 7.965286,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "name": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "annual_utilization_factor": 0.512215,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "name": "2021::PHIUS_NR::Office_Workspace_Semiopen",
                "watts_per_m2": 6.888896,
            },
        },
    },
    "2021::PHIUS_NR::Office_Workspace_Closed": {
        "name": "Office Workspace Closed",
        "hb_base_program": "2019::MediumOffice::ClosedOffice",
        "protocol": "PHIUS_NonRes",
        "description": "Personal office (single occupant)",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", ""],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Office_Workspace_Closed",
                "identifier": "2021::PHIUS_NR::Office_Workspace_Closed",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.7,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Closed",
                "name": "2021::PHIUS_NR::Office_Workspace_Closed",
                "people_per_area": 0.051129,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Closed",
                "name": "2021::PHIUS_NR::Office_Workspace_Closed",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.7,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Closed",
                "name": "2021::PHIUS_NR::Office_Workspace_Closed",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 7.965286,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Closed",
                "name": "2021::PHIUS_NR::Office_Workspace_Closed",
                "annual_utilization_factor": 0.512215,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Office_Workspace_Closed",
                "name": "2021::PHIUS_NR::Office_Workspace_Closed",
                "watts_per_m2": 6.888896,
            },
        },
    },
    "2021::PHIUS_NR::Other_Habitable": {
        "name": "Other Habitable",
        "hb_base_program": "2019::LargeOffice::OpenOffice",
        "protocol": "PHIUS_NonRes",
        "description": "Other Habitable Room",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::LargeOffice::OpenOffice",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Other_Habitable",
                "identifier": "2021::PHIUS_NR::Other_Habitable",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Other_Habitable",
                "name": "2021::PHIUS_NR::Other_Habitable",
                "people_per_area": 0.056511,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Other_Habitable",
                "name": "2021::PHIUS_NR::Other_Habitable",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Other_Habitable",
                "name": "2021::PHIUS_NR::Other_Habitable",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 6.565979,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Other_Habitable",
                "name": "2021::PHIUS_NR::Other_Habitable",
                "annual_utilization_factor": 0.512215,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Other_Habitable",
                "name": "2021::PHIUS_NR::Other_Habitable",
                "watts_per_m2": 7.642369,
            },
        },
    },
    "2021::PHIUS_NR::Other_Non_Habitable": {
        "name": "Other Non Habitable",
        "hb_base_program": "2019::LargeOffice::Storage",
        "protocol": "PHIUS_NonRes",
        "description": "Auxiliary spaces without habitable rooms",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::LargeOffice::Storage",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Other_Non_Habitable",
                "identifier": "2021::PHIUS_NR::Other_Non_Habitable",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Other_Non_Habitable",
                "name": "2021::PHIUS_NR::Other_Non_Habitable",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Other_Non_Habitable",
                "name": "2021::PHIUS_NR::Other_Non_Habitable",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Other_Non_Habitable",
                "name": "2021::PHIUS_NR::Other_Non_Habitable",
                "target_lux": 100,
                "target_lux_height": 0.8,
                "watts_per_m2": 4.090282,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Other_Non_Habitable",
                "name": "2021::PHIUS_NR::Other_Non_Habitable",
                "annual_utilization_factor": 0.512215,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Other_Non_Habitable",
                "name": "2021::PHIUS_NR::Other_Non_Habitable",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::Restaurant": {
        "name": "Restaurant",
        "hb_base_program": "2019::FullServiceRestaurant::Dining",
        "protocol": "PHIUS_NonRes",
        "description": "2021::PHIUS_NR::Restaurant",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::FullServiceRestaurant::Dining",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Restaurant",
                "identifier": "2021::PHIUS_NR::Restaurant",
                "start_hour": 10,
                "end_hour": 24,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Restaurant",
                "name": "2021::PHIUS_NR::Restaurant",
                "people_per_area": 0.753474,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Restaurant",
                "name": "2021::PHIUS_NR::Restaurant",
                "daily_operating_hours": 14,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Restaurant",
                "name": "2021::PHIUS_NR::Restaurant",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 6.45834,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Restaurant",
                "name": "2021::PHIUS_NR::Restaurant",
                "annual_utilization_factor": 0.164583,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Restaurant",
                "name": "2021::PHIUS_NR::Restaurant",
                "watts_per_m2": 64.927845,
            },
        },
    },
    "2021::PHIUS_NR::Restroom_Public": {
        "name": "Restroom Public",
        "hb_base_program": "2019::MediumOffice::Restroom",
        "protocol": "PHIUS_NonRes",
        "description": "Toilets and sanitary facilities in non residential buildings",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::MediumOffice::Restroom",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Restroom_Public",
                "identifier": "2021::PHIUS_NR::Restroom_Public",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Restroom_Public",
                "name": "2021::PHIUS_NR::Restroom_Public",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Restroom_Public",
                "name": "2021::PHIUS_NR::Restroom_Public",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Restroom_Public",
                "name": "2021::PHIUS_NR::Restroom_Public",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 6.781257,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Restroom_Public",
                "name": "2021::PHIUS_NR::Restroom_Public",
                "annual_utilization_factor": 0.467636,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Restroom_Public",
                "name": "2021::PHIUS_NR::Restroom_Public",
                "watts_per_m2": 2.906253,
            },
        },
    },
    "2021::PHIUS_NR::Department_Store": {
        "name": "Department Store",
        "hb_base_program": "2019::Retail::Core_Retail",
        "protocol": "PHIUS_NonRes",
        "description": "Retail shop/Department store",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::Retail::Core_Retail",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Department_Store",
                "identifier": "2021::PHIUS_NR::Department_Store",
                "start_hour": 8,
                "end_hour": 20,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Department_Store",
                "name": "2021::PHIUS_NR::Department_Store",
                "people_per_area": 0.161459,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Department_Store",
                "name": "2021::PHIUS_NR::Department_Store",
                "daily_operating_hours": 12,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Department_Store",
                "name": "2021::PHIUS_NR::Department_Store",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 11.302095,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Department_Store",
                "name": "2021::PHIUS_NR::Department_Store",
                "annual_utilization_factor": 0.519583,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Department_Store",
                "name": "2021::PHIUS_NR::Department_Store",
                "watts_per_m2": 3.22917,
            },
        },
    },
    "2021::PHIUS_NR::Grocery": {
        "name": "Grocery",
        "hb_base_program": "2019::SuperMarket::Sales",
        "description": "Retail shop/department store (food department with refrigerated products)",
        "protocol": "PHIUS_NonRes",
        "description": "",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", "2019::SuperMarket::Sales"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Grocery",
                "identifier": "2021::PHIUS_NR::Grocery",
                "start_hour": 8,
                "end_hour": 20,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Grocery",
                "name": "2021::PHIUS_NR::Grocery",
                "people_per_area": 0.086111,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Grocery",
                "name": "2021::PHIUS_NR::Grocery",
                "daily_operating_hours": 12,
                "annual_utilization_days": 300,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Grocery",
                "name": "2021::PHIUS_NR::Grocery",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 11.302095,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Grocery",
                "name": "2021::PHIUS_NR::Grocery",
                "annual_utilization_factor": 0.606735,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Grocery",
                "name": "2021::PHIUS_NR::Grocery",
                "watts_per_m2": 10.979178,
            },
        },
    },
    "2021::PHIUS_NR::Storage_Archive": {
        "name": "Storage Archive",
        "hb_base_program": "2019::Warehouse::Fine",
        "protocol": "PHIUS_NonRes",
        "description": "Storeroom technical equipment room or archive",
        "source": ["PHIUS_Certification_Guidebook_v3.02_N10", "2019::Warehouse::Fine"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Storage_Archive",
                "identifier": "2021::PHIUS_NR::Storage_Archive",
                "start_hour": 7,
                "end_hour": 18,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.02,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Storage_Archive",
                "name": "2021::PHIUS_NR::Storage_Archive",
                "people_per_area": 0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Storage_Archive",
                "name": "2021::PHIUS_NR::Storage_Archive",
                "daily_operating_hours": 11,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Storage_Archive",
                "name": "2021::PHIUS_NR::Storage_Archive",
                "target_lux": 100,
                "target_lux_height": 0.8,
                "watts_per_m2": 7.427091,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Storage_Archive",
                "name": "2021::PHIUS_NR::Storage_Archive",
                "annual_utilization_factor": 0.427397,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Storage_Archive",
                "name": "2021::PHIUS_NR::Storage_Archive",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::School_Auditorium": {
        "name": "School Auditorium",
        "hb_base_program": "2019::SecondarySchool::Auditorium",
        "protocol": "PHIUS_NonRes",
        "description": "Lecture room, auditorium",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::SecondarySchool::Auditorium",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::School_Auditorium",
                "identifier": "2021::PHIUS_NR::School_Auditorium",
                "start_hour": 8,
                "end_hour": 18,
                "annual_utilization_days": 150,
                "relative_utilization_factor": 0.75,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::School_Auditorium",
                "name": "2021::PHIUS_NR::School_Auditorium",
                "people_per_area": 1.614587,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::School_Auditorium",
                "name": "2021::PHIUS_NR::School_Auditorium",
                "daily_operating_hours": 12,
                "annual_utilization_days": 150,
                "relative_utilization_factor": 0.7,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::School_Auditorium",
                "name": "2021::PHIUS_NR::School_Auditorium",
                "target_lux": 500,
                "target_lux_height": 0.8,
                "watts_per_m2": 6.565979,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::School_Auditorium",
                "name": "2021::PHIUS_NR::School_Auditorium",
                "annual_utilization_factor": 0.462476,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::School_Auditorium",
                "name": "2021::PHIUS_NR::School_Auditorium",
                "watts_per_m2": 4.951394,
            },
        },
    },
    "2021::PHIUS_NR::Theater_Seating": {
        "name": "Theater Seating",
        "hb_base_program": "2019::Courthouse::Courtroom",
        "protocol": "PHIUS_NonRes",
        "description": "Spectators and audience area of theaters and event locations",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::Courthouse::Courtroom",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Theater_Seating",
                "identifier": "2021::PHIUS_NR::Theater_Seating",
                "start_hour": 19,
                "end_hour": 23,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Seating",
                "name": "2021::PHIUS_NR::Theater_Seating",
                "people_per_area": 0.753474,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Seating",
                "name": "2021::PHIUS_NR::Theater_Seating",
                "daily_operating_hours": 4,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Seating",
                "name": "2021::PHIUS_NR::Theater_Seating",
                "target_lux": 200,
                "target_lux_height": 0.8,
                "watts_per_m2": 12.91668,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Seating",
                "name": "2021::PHIUS_NR::Theater_Seating",
                "annual_utilization_factor": 0.473153,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Seating",
                "name": "2021::PHIUS_NR::Theater_Seating",
                "watts_per_m2": 0,
            },
        },
    },
    "2021::PHIUS_NR::Theater_Lobby": {
        "name": "Theater Lobby",
        "hb_base_program": "2019::MediumOffice::Lobby",
        "protocol": "PHIUS_NonRes",
        "description": "Foyer (theaters and event locations)",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::MediumOffice::Lobby",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Theater_Lobby",
                "identifier": "2021::PHIUS_NR::Theater_Lobby",
                "start_hour": 19,
                "end_hour": 23,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Lobby",
                "name": "2021::PHIUS_NR::Theater_Lobby",
                "people_per_area": 0.107639,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Lobby",
                "name": "2021::PHIUS_NR::Theater_Lobby",
                "daily_operating_hours": 4,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Lobby",
                "name": "2021::PHIUS_NR::Theater_Lobby",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 9.041676,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Lobby",
                "name": "2021::PHIUS_NR::Theater_Lobby",
                "annual_utilization_factor": 0.467636,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Lobby",
                "name": "2021::PHIUS_NR::Theater_Lobby",
                "watts_per_m2": 2.906253,
            },
        },
    },
    "2021::PHIUS_NR::Theater_Stage": {
        "name": "Theater Stage",
        "hb_base_program": "2019::MediumOffice::OpenOffice",
        "protocol": "PHIUS_NonRes",
        "description": "Stage (theaters and event locations)",
        "source": [
            "PHIUS_Certification_Guidebook_v3.02_N10",
            "2019::MediumOffice::OpenOffice",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_NR::Theater_Stage",
                "identifier": "2021::PHIUS_NR::Theater_Stage",
                "start_hour": 13,
                "end_hour": 23,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Stage",
                "name": "2021::PHIUS_NR::Theater_Stage",
                "people_per_area": 0.056511,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Stage",
                "name": "2021::PHIUS_NR::Theater_Stage",
                "daily_operating_hours": 10,
                "annual_utilization_days": 250,
                "relative_utilization_factor": 0.6,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Stage",
                "name": "2021::PHIUS_NR::Theater_Stage",
                "target_lux": 1000,
                "target_lux_height": 0.8,
                "watts_per_m2": 6.565979,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_NR::Theater_Stage",
                "name": "2021::PHIUS_NR::Theater_Stage",
                "annual_utilization_factor": 0.467636,
            },
            "loads": {
                "identifier": "2021::PHIUS_NR::Theater_Stage",
                "name": "2021::PHIUS_NR::Theater_Stage",
                "watts_per_m2": 10.333344,
            },
        },
    },
}

# Programs from:
# - PHIUS_Multi-Family_Calculator- 021.03.23.xls
PHIUS_MF_Calculator = {
    "2021::PHIUS_MF::Central_Restroom": {
        "name": "Central Restroom",
        "hb_base_program": "2019::SmallHotel::PublicRestroom",
        "protocol": "PHIUS_MultiFamily",
        "description": "Central Restroom",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::SmallHotel::PublicRestroom",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Central_Restroom",
                "identifier": "2021::PHIUS_MF::Central_Restroom",
                "start_hour": 11.2,
                "end_hour": 12.8,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Central_Restroom",
                "name": "2021::PHIUS_MF::Central_Restroom",
                "people_per_area": 0.030677,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Central_Restroom",
                "name": "2021::PHIUS_MF::Central_Restroom",
                "daily_operating_hours": 1.6,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Central_Restroom",
                "name": "2021::PHIUS_MF::Central_Restroom",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 9.687519375,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Central_Restroom",
                "name": "2021::PHIUS_MF::Central_Restroom",
                "annual_utilization_factor": 0.07,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Central_Restroom",
                "name": "2021::PHIUS_MF::Central_Restroom",
                "watts_per_m2": 0.0,
            },
        },
    },
    "2021::PHIUS_MF::Common_Laundry": {
        "name": "Common Laundry",
        "hb_base_program": "2019::SmallHotel::Laundry",
        "protocol": "PHIUS_MultiFamily",
        "description": "Common Laundry",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::SmallHotel::Laundry",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Common_Laundry",
                "identifier": "2021::PHIUS_MF::Common_Laundry",
                "start_hour": 0,
                "end_hour": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Laundry",
                "name": "2021::PHIUS_MF::Common_Laundry",
                "people_per_area": 0.112483,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Common_Laundry",
                "name": "2021::PHIUS_MF::Common_Laundry",
                "daily_operating_hours": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Laundry",
                "name": "2021::PHIUS_MF::Common_Laundry",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 7.534737292,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Common_Laundry",
                "name": "2021::PHIUS_MF::Common_Laundry",
                "annual_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Laundry",
                "name": "2021::PHIUS_MF::Common_Laundry",
                "watts_per_m2": 0.0,
            },
        },
    },
    "2021::PHIUS_MF::Common_Mail": {
        "name": "Common Mail",
        "hb_base_program": "2019::MediumOffice::Lobby",
        "protocol": "PHIUS_MultiFamily",
        "description": "Common Mail",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::MediumOffice::Lobby",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Common_Mail",
                "identifier": "2021::PHIUS_MF::Common_Mail",
                "start_hour": 6,
                "end_hour": 18,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Mail",
                "name": "2021::PHIUS_MF::Common_Mail",
                "people_per_area": 0.112483,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Common_Mail",
                "name": "2021::PHIUS_MF::Common_Mail",
                "daily_operating_hours": 12,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Mail",
                "name": "2021::PHIUS_MF::Common_Mail",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 30.13894917,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Common_Mail",
                "name": "2021::PHIUS_MF::Common_Mail",
                "annual_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Mail",
                "name": "2021::PHIUS_MF::Common_Mail",
                "watts_per_m2": 0.0,
            },
        },
    },
    "2021::PHIUS_MF::Common_Office": {
        "name": "Common Office",
        "hb_base_program": "2019::MidriseApartment::Office",
        "protocol": "PHIUS_MultiFamily",
        "description": "Common Office",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::MidriseApartment::Office",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Common_Office",
                "identifier": "2021::PHIUS_MF::Common_Office",
                "start_hour": 7.5,
                "end_hour": 16.5,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Office",
                "name": "2021::PHIUS_MF::Common_Office",
                "people_per_area": 0.011302,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Common_Office",
                "name": "2021::PHIUS_MF::Common_Office",
                "daily_operating_hours": 9,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Office",
                "name": "2021::PHIUS_MF::Common_Office",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 10.76391042,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Common_Office",
                "name": "2021::PHIUS_MF::Common_Office",
                "annual_utilization_factor": 0.375,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Common_Office",
                "name": "2021::PHIUS_MF::Common_Office",
                "watts_per_m2": 42.30216794,
            },
        },
    },
    "2021::PHIUS_MF::Storage_or_Equip": {
        "name": "Storage / Equipment",
        "hb_base_program": "2019::LargeOffice::Storage",
        "protocol": "PHIUS_MultiFamily",
        "description": "Storage / Equipment",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::LargeOffice::Storage",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Storage_or_Equip",
                "identifier": "2021::PHIUS_MF::Storage_or_Equip",
                "start_hour": 0,
                "end_hour": 1,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Storage_or_Equip",
                "name": "2021::PHIUS_MF::Storage_or_Equip",
                "people_per_area": 0.0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Storage_or_Equip",
                "name": "2021::PHIUS_MF::Storage_or_Equip",
                "daily_operating_hours": 1,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Storage_or_Equip",
                "name": "2021::PHIUS_MF::Storage_or_Equip",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 16.14586563,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Storage_or_Equip",
                "name": "2021::PHIUS_MF::Storage_or_Equip",
                "annual_utilization_factor": 0.0416,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Storage_or_Equip",
                "name": "2021::PHIUS_MF::Storage_or_Equip",
                "watts_per_m2": 0.0,
            },
        },
    },
    "2021::PHIUS_MF::Elevator": {
        "name": "Elevator",
        "hb_base_program": "2019::LargeOffice::Elevator Shaft",
        "protocol": "PHIUS_MultiFamily",
        "description": "Elevator",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::LargeOffice::Elevator Shaft",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Elevator",
                "identifier": "2021::PHIUS_MF::Elevator",
                "start_hour": 0,
                "end_hour": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Elevator",
                "name": "2021::PHIUS_MF::Elevator",
                "people_per_area": 0.0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Elevator",
                "name": "2021::PHIUS_MF::Elevator",
                "daily_operating_hours": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Elevator",
                "name": "2021::PHIUS_MF::Elevator",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 13.45488802,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Elevator",
                "name": "2021::PHIUS_MF::Elevator",
                "annual_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Elevator",
                "name": "2021::PHIUS_MF::Elevator",
                "watts_per_m2": 0.0,
            },
        },
    },
    "2021::PHIUS_MF::Corridor": {
        "name": "Indoor Corridor",
        "hb_base_program": "2019::MidriseApartment::Corridor",
        "protocol": "PHIUS_MultiFamily",
        "description": "Indoor Corridor",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::MidriseApartment::Corridor",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Corridor",
                "identifier": "2021::PHIUS_MF::Corridor",
                "start_hour": 0,
                "end_hour": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Corridor",
                "name": "2021::PHIUS_MF::Corridor",
                "people_per_area": 0.0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Corridor",
                "name": "2021::PHIUS_MF::Corridor",
                "daily_operating_hours": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Corridor",
                "name": "2021::PHIUS_MF::Corridor",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 5.381955208,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Corridor",
                "name": "2021::PHIUS_MF::Corridor",
                "annual_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Corridor",
                "name": "2021::PHIUS_MF::Corridor",
                "watts_per_m2": 0.0,
            },
        },
    },
    "2021::PHIUS_MF::Multi_Purpose": {
        "name": "Multi-Purpose",
        "hb_base_program": "2019::SmallHotel::Meeting",
        "protocol": "PHIUS_MultiFamily",
        "description": "Multi-Purpose / Community",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::SmallHotel::Meeting",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Multi_Purpose",
                "identifier": "2021::PHIUS_MF::Multi_Purpose",
                "start_hour": 6,
                "end_hour": 18,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Multi_Purpose",
                "name": "2021::PHIUS_MF::Multi_Purpose",
                "people_per_area": 0.538196,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Multi_Purpose",
                "name": "2021::PHIUS_MF::Multi_Purpose",
                "daily_operating_hours": 12,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Multi_Purpose",
                "name": "2021::PHIUS_MF::Multi_Purpose",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 11.84030146,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Multi_Purpose",
                "name": "2021::PHIUS_MF::Multi_Purpose",
                "annual_utilization_factor": 0.5,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Multi_Purpose",
                "name": "2021::PHIUS_MF::Multi_Purpose",
                "watts_per_m2": 0.0,
            },
        },
    },
    "2021::PHIUS_MF::Workout": {
        "name": "Workout",
        "hb_base_program": "2019::PrimarySchool::Gym",
        "protocol": "PHIUS_MultiFamily",
        "description": "Workout",
        "source": [
            "PHIUS_Multi-Family_Calculator- 021.03.23.xls",
            "2019::PrimarySchool::Gym",
        ],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Workout",
                "identifier": "2021::PHIUS_MF::Workout",
                "start_hour": 6,
                "end_hour": 22,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Workout",
                "name": "2021::PHIUS_MF::Workout",
                "people_per_area": 0.322917,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Workout",
                "name": "2021::PHIUS_MF::Workout",
                "daily_operating_hours": 16,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Workout",
                "name": "2021::PHIUS_MF::Workout",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 9.687519375,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Workout",
                "name": "2021::PHIUS_MF::Workout",
                "annual_utilization_factor": 0.667,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Workout",
                "name": "2021::PHIUS_MF::Workout",
                "watts_per_m2": 12.04,
            },
        },
    },
    "2021::PHIUS_MF::Stair": {
        "name": "Indoor Stair",
        "hb_base_program": "2019::MediumOffice::Stair",
        "protocol": "PHIUS_MultiFamily",
        "description": "Indoor Stairwell",
        "source": ["2019::MediumOffice::Stair"],
        "people": {
            "schedule": {
                "name": "2021::PHIUS_MF::Stair",
                "identifier": "2021::PHIUS_MF::Stair",
                "start_hour": 0,
                "end_hour": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 0.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Stair",
                "name": "2021::PHIUS_MF::Stair",
                "people_per_area": 0.0,
            },
        },
        "lighting": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Stair",
                "name": "2021::PHIUS_MF::Stair",
                "daily_operating_hours": 24,
                "annual_utilization_days": 365,
                "relative_utilization_factor": 0.305919,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Stair",
                "name": "2021::PHIUS_MF::Stair",
                "target_lux": 300,
                "target_lux_height": 0.8,
                "watts_per_m2": 5.274311,
            },
        },
        "elec_equipment": {
            "schedule": {
                "identifier": "2021::PHIUS_MF::Stair",
                "name": "2021::PHIUS_MF::Stair",
                "annual_utilization_factor": 1.0,
            },
            "loads": {
                "identifier": "2021::PHIUS_MF::Stair",
                "name": "2021::PHIUS_MF::Stair",
                "watts_per_m2": 0.0,
            },
        },
    },
}

# -- Full Library
PHIUS_library = {}  # type: Dict[str, Dict]
PHIUS_library.update(PHIUS_Non_Res)
PHIUS_library.update(PHIUS_MF_Calculator)



# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""PH Properties classes for Space objects."""

try:
    from typing import Any, Optional
except:
    pass  # IronPython

from honeybee import properties


class SpaceEnergyProperties(properties._Properties):
    def __init__(self, _host):
        self._host = _host
        self.id_num = 0

    @property
    def host(self):
        return self._host

    def to_dict(self, abridged=False, include=None):
        # type: (bool, Optional[list]) -> dict[str, Any]
        """Convert properties to dictionary.

        Args:
            abridged: Boolean to note whether the full dictionary describing the
                object should be returned (False) or just an abridged version (True).
                Default: False.
            include: A list of keys to be included in dictionary.
                If None all the available keys will be included.
        """
        d = {}

        if abridged:
            d["type"] = "SpaceEnergyPropertiesAbridged"
        else:
            d["type"] = "SpaceEnergyProperties"

        d["id_num"] = self.id_num

        return {"energy": d}

    @classmethod
    def from_dict(cls, _input_dict, _host):
        # type: (dict, Any) -> SpaceEnergyProperties
        assert "SpaceEnergyProperties" in _input_dict["type"], "Expected SpaceEnergyProperties. Got {}.".format(
            _input_dict["type"]
        )

        new_prop = cls(_host)
        new_prop.id_num = _input_dict.get("id_num", 0)

        return new_prop

    def __str__(self):
        return "{}()".format(self.__class__.__name__)

    def __repr__(self):
        return str(self)

    def ToString(self):
        return str(self)



# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""Utility functions for cleaning and handling user-inputs"""


try:
    from typing import Any, List, Optional, TypeVar

    T = TypeVar("T")
except ImportError:
    pass  # Python 3

try:
    from scriptcontext import sticky  # type: ignore
except ImportError:
    pass  # Not in Rhino Grasshopper

import re


def input_to_int(_input_value, _default=None):
    # type: (Any, Any) -> int | None
    """For 'selection' type inputs, clean and convert input to int.

    ie: if the Grasshopper input allows:
        "1-A First Type"
        "2-A Second Type"

    will strip the string part and return just the integer value, or raise SelectionInputError.
    """

    if not _input_value:
        return _default

    # "\d" is a special character in regular expressions that matches any digit from 0 to 9.
    # "+" is a quantifier that specifies that the preceding pattern (in this case, \d) should match one or more times.
    # So the regular expression "\d+" will match one or more consecutive digits in a string.
    result = re.search(r"\d+", str(_input_value))
    try:
        return int(result.group(0))
    except ValueError:
        msg = 'Input Error: Cannot use input "{}" [{}].\n' "Please check the allowable input options.".format(
            _input_value, type(_input_value)
        )
        raise Exception(msg)
    except AttributeError as e:
        # If no 'group', ie: no int part supplied in the string
        msg = 'Error trying to find the integer input part of input: "{}", type: {}'.format(
            _input_value, type(_input_value)
        )
        raise Exception(msg)


def clean_tree_get(_tree, _i, _default=None):
    try:
        return _tree.Branch(_i)
    except:
        try:
            return _tree.Branch(0)
        except:
            return _default


def clean_get(_list, _i, _default=None):
    # type: (List[T], int, Optional[T]) -> Optional[T]
    """Get list item cleanly based on index pos. If IndexError, will try getting _list[0] instead.

    This is useful for gh-components with multiple list inputs which are sometimes
    the same length, and sometimes not the same length.

    Arguments:
    ---------
        * _list: Any iterable to get the item from.
        * _i: The index position to try and get
        * _default: The optional default value to use if _list[0] fails.

    Returns:
    --------
        * Any
    """
    try:
        return _list[_i]
    except IndexError:
        try:
            return _list[0]
        except IndexError:
            return _default


def cleaner_get(_list, _i, _default):
    # type: (List[T], int, T) -> T
    """Get list item cleanly based on index pos. If IndexError, will try getting _list[0] instead.

    This function *requires* a default values to be supplied, and therefor will never return None (unless
    the default value is None). This is more type-safe than the 'clean_get' function.

    This is useful for gh-components with multiple list inputs which are sometimes
    the same length, and sometimes not the same length.

    Arguments:
    ---------
        * _list: Any iterable to get the item from.
        * _i: The index position to try and get
        * _default: A required default value to use if _list[0] fails.

    Returns:
    --------
        * Any
    """
    try:
        return _list[_i]
    except IndexError:
        try:
            return _list[0]
        except IndexError:
            return _default


def memoize(func):
    """Simple caching decorator using function arguments as key.

    Uses the Grasshopper 'sticky' dict to store values.

    https://book.pythontips.com/en/latest/function_caching.html

    Usage:
    >>> @memoize
    >>> def fibonacci(n):
    >>>     if n < 2: return n
    >>>    return fibonacci(n - 1) + fibonacci(n - 2)
    >>>
    >>> fibonacci(25)
    """

    def wrapper(*args, **kwargs):
        try:
            return sticky[args]
        except KeyError:
            rv = func(*args, **kwargs)
            sticky[args] = rv
            return rv

    return wrapper



# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""HB-Shade Passive House (PH) Properties."""
try:
    from typing import Any
except ImportError:
    pass  # Python 2.7


class ShadePhProperties(object):
    def __init__(self, _host):
        self._host = _host
        self.id_num = 0

    @property
    def host(self):
        return self._host

    def duplicate(self, new_host=None):
        # type: (Any) -> ShadePhProperties
        _host = new_host or self._host
        new_properties_obj = ShadePhProperties(_host)
        new_properties_obj.id_num = self.id_num

        return new_properties_obj

    def ToString(self):
        return self.__repr__()

    def __repr__(self):
        return "Shade Passive House Properties: [host: {}]".format(self.host.display_name)

    def to_dict(self, abridged=False):
        # type: (bool) -> dict[str, dict]
        d = {}
        t = "ShadePhProperties" if not abridged else "ShadePhPropertiesAbridged"
        d.update({"type": t})
        d.update({"id_num": self.id_num})

        return {"ph": d}

    @classmethod
    def from_dict(cls, data, host):
        # type: (dict, Any) -> ShadePhProperties
        assert data["type"] == "ShadePhProperties", "Expected ShadePhProperties. Got {}.".format(data["type"])

        new_prop = cls(host)
        new_prop.id_num = data.get("id_num", 0)

        return new_prop



# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""Package: Honeybee-PH-Utils

These classes are designed to be used within a Honeybee-editing environment, such as Rhino or 
Grasshopper. These modules include a variety of helper functions used throughout HBPH.
"""

# load all functions that extends honeybee core library
# Make sure the load `honeybee_energy` before anything else to avoid import errors.
import honeybee_energy._extend_honeybee
